#!/bin/bash
. $MX_SCRIPT_PATH/.mx_private.sh

#################################################
# Table names
#################################################
MX_CONTROL_TABLE=mxTableControl

#################################################
# FUNCTION:
#	sql query with short options
#   Use for result like 'val1 val2 val3'
#################################################
gb_sql_query()
{
    _sql_query "${SQLITE_OPT}" "$1" 
}

#################################################
# FUNCTION:
#	import all columns values of a single row to the script 
#   Parameter: query_str, like SELECT * from table where id=1  
#   (This query string should only get 1 row from the table)
#################################################
gb_sql_import_row_var() 
{
    local query=$1
	local allow_empty=$2

    PREP=`gb_sql_query_lopt "$query"`
    if [ $? -ne 0 ]; then
        _perror "gb_sql_import_row_var: Incorrect query = $1"
        exit
    fi

    if [ -z "${PREP}" ]; then
        if [ $2 -ne 1 ]; then
            _perror "gb_sql_import_row_var: Your query result is empty!"
            return 1
        else
            gb_import_var "${PREP}"
            return 0
        fi
    fi

    # check if more than 1 row
    gb_row_delim=`echo ${PREP} | awk '/^$/' | wc -l`
    if [ $gb_row_delim -ne 0 ] ; then 
        _perror "gb_sql_import_row_var: Your query result has more than 1 row!"
        return 1
    fi 

    gb_import_var "${PREP}"
    return 0
}

#################################################
# FUNCTION:
#	the the row_count of table
#################################################
gb_table_get_row_count() 
{
	local table=$1
	local count=`gb_sql_query "Select count(*) from $table"`
	echo $count
}

#################################################
# FUNCTION:
# 	due to mxTableControl only can record if a table is changed (not the times of changing)
# 	so please wait for changable
#################################################
gb_table_set_change()
{
	local table=$1

	status=`gb_sql_query "Select status from mxTableControl where tableName='$table'"`
	if [ "$status" == "" ]; then
		echo "Can't find table $table in the mxTableControl!"
		exit 1
	fi

	while [ "$status" -eq "1" ]; do 
		echo "Wait until Table $table is changable"
		sleep 1
		status=`gb_sql_query "Select status from mxTableControl where tableName='$table'"`
	done
	gb_sql_query "Update mxTableControl set status=1 where tableName='$table'"
}


#################################################
#   Param: string file_name
#################################################
gb_file_append ()
{
	str=$1
	file=$2

	echo "$str" >> $file
}

#################################################
#   Param: file_name
#################################################
gb_file_clean ()
{
	file=$1
	
	:> $file
}

#################################################
#	Param: file_name
#################################################
gb_file_delete ()
{
	file=$1

	rm -f $file
}

#################################################
#   Param: src_file des_file
#################################################
gb_file_save ()
{
	src_file=$1
	des_file=$2

	cat $src_file > $des_file
}

#################################################
#   Debug function: 
#   enable by set gb_debug_enable = 1
#################################################
gb_debug()
{
	if [ "$gb_debug_enable" == "1" ]; then 
		echo $1
	fi
}

gb_debug_time()
{
	if [ "$gb_debug_enable" == "1" ]; then
		tag=$1
		local now_time=`date +%s.%N`
		echo "<$tag>$now_time"
	fi
}

gb_print()
{
	if [ "$gb_print_enable" == "1" ]; then 
		echo $1
	fi
}

gb_error()
{
	echo Error: $1
}

gb_control_table_clear()
{
	local table=$1

	gb_sql_query "UPDATE controlManagement set commits=0 WHERE actions='$table'"
}

gb_control_table_get()
{
	local table=$1

	local res=`gb_sql_query "Select commits from controlManagement WHERE actions='$table'"`
	echo $res
}

